@@ -57,6 +57,7 @@ struct UICStruct {
 	gboolean getSms;
 	gulong sigId;
 	gboolean phoneOpened;
+	gboolean noConfig;
 };
 typedef struct UICStruct UIComponents;
 
@@ -97,7 +98,7 @@ static void  quit_event( UIComponents *uic, guint callback_action, GtkWidget *me
 		uic->phoneOpened = !(uic->phoneOpened);
 		gn_lib_phone_close(state);
 	}
-		
+
         gn_lib_phoneprofile_free(&state);
         gn_lib_library_free();
 
@@ -260,6 +261,8 @@ void notify_sms(gn_sms *message, struct gn_statemachine *state, UIComponents *ui
 void notify_call(gn_call_status call_status, gn_call_info *call_info, struct gn_statemachine *state, UIComponents *uic) {
 	/* in this callback function you can't use those libgnokii functions that send a packet */
 	
+	g_printf("\n===== ===== Incoming Call ===== =====\n");
+	
 	if (call_status != GN_CALL_Incoming) return;
 	
 	hildon_banner_show_informationf(GTK_WIDGET(gtk_widget_get_toplevel(uic->searchEntry)), GTK_STOCK_DIALOG_INFO, _("A call from %s"), call_info->number);
@@ -272,7 +275,6 @@ gboolean getCalls(GtkWidget *topLevel, UIComponents *uic) {
 	gn_data		data;
 	gn_error	error = GN_ERR_NONE;
 	
-	uic->getCalls = !(uic->getCalls);
 	if (uic->getCalls) {
 		if (!uic->phoneOpened) {
 			error = gn_lib_phone_open(state);
@@ -287,7 +289,6 @@ gboolean getCalls(GtkWidget *topLevel, UIComponents *uic) {
 		}
 		if (error != GN_ERR_NONE) {
 			hildon_banner_show_informationf(topLevel, GTK_STOCK_DIALOG_INFO, _("This driver doesn't support call signaling.\n(%s)"), gn_error_print(error));
-			uic->getCalls = !(uic->getCalls);
 			if (uic->phoneOpened) {
 				uic->phoneOpened = !(uic->phoneOpened);
 				gn_lib_phone_close(state);
@@ -310,7 +311,9 @@ gboolean getCalls(GtkWidget *topLevel, UIComponents *uic) {
 }
 
 void on_menu_getCalls(GtkCheckMenuItem *checkMenuitem, UIComponents *uic) {
+	uic->getCalls = !(uic->getCalls);
 	if (getCalls(GTK_WIDGET(gtk_widget_get_toplevel(GTK_WIDGET(checkMenuitem))), uic) == FALSE) {
+		uic->getCalls = !(uic->getCalls);
 		gtk_check_menu_item_set_active(checkMenuitem, FALSE);
 	}
 }
@@ -319,13 +322,13 @@ gboolean getSms(GtkWidget *topLevel, UIComponents *uic) {
 	gn_data		data;
 	gn_error	error = GN_ERR_NONE;
 	
-	uic->getSms = !(uic->getSms);
 	if (uic->getSms) {
 		if (!uic->phoneOpened) {
 			error = gn_lib_phone_open(state);
 		}
 		/* Set up so that we get notified of incoming sms, if supported by the driver */
 		if (error == GN_ERR_NONE) {
+			uic->phoneOpened = TRUE;
 			gn_data_clear(&data);
 			data.on_sms = notify_sms;
 			data.callback_data = uic;
@@ -333,7 +336,6 @@ gboolean getSms(GtkWidget *topLevel, UIComponents *uic) {
 		}
 		if (error != GN_ERR_NONE) {
 			hildon_banner_show_informationf(topLevel, GTK_STOCK_DIALOG_INFO, _("This driver doesn't support sms signaling.\n(%s)"), gn_error_print(error));
-			uic->getSms = !(uic->getSms);
 			if (uic->phoneOpened) {
 				uic->phoneOpened = !(uic->phoneOpened);
 				gn_lib_phone_close(state);
@@ -356,7 +358,9 @@ gboolean getSms(GtkWidget *topLevel, UIComponents *uic) {
 }
 
 void on_menu_getSms(GtkCheckMenuItem *checkMenuitem, UIComponents *uic) {
+	uic->getSms = !(uic->getSms);
 	if (getSms(GTK_WIDGET(gtk_widget_get_toplevel(GTK_WIDGET(checkMenuitem))), uic) == FALSE) {
+		uic->getSms = !(uic->getSms);
 		gtk_check_menu_item_set_active(checkMenuitem, FALSE);
 	}
 }
@@ -378,11 +382,13 @@ GtkMenu *create_menus(UIComponents *uic) {
 	menuItem = gtk_check_menu_item_new_with_label (_("Notify me on incoming call"));
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menuItem), uic->getCalls);
 	g_signal_connect (G_OBJECT (menuItem), "toggled", G_CALLBACK (on_menu_getCalls), (gpointer) uic);
+	gtk_widget_set_sensitive(menuItem, !uic->noConfig);
 	gtk_menu_append(menuBar, menuItem);
 	
 	menuItem = gtk_check_menu_item_new_with_label (_("Notify me on SMS reception"));
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menuItem), uic->getSms);
 	g_signal_connect (G_OBJECT (menuItem), "toggled", G_CALLBACK (on_menu_getSms), (gpointer) uic);
+	gtk_widget_set_sensitive(menuItem, !uic->noConfig);
 	gtk_menu_append(menuBar, menuItem);
 	
 	gtk_menu_append(menuBar, gtk_separator_menu_item_new());
@@ -594,7 +600,8 @@ static guint dialGsm(gchar *number, gchar **message, gboolean phoneOpened) {
 				
 	/* initialise the connection */
 	if (!phoneOpened && (error = gn_lib_phone_open(state)) != GN_ERR_NONE) {
-		g_print("Telephone interface init failed: %s Quitting.\n", gn_error_print(error));
+		g_printf("Telephone interface init failed: %s Quitting.\n", gn_error_print(error));
+		*message=g_strdup_printf("Telephone interface init failed: %s Quitting.", gn_error_print(error));
 		return 1;
 	}
 
@@ -605,10 +612,11 @@ static guint dialGsm(gchar *number, gchar **message, gboolean phoneOpened) {
 	gn_data_clear(&gdata);
 	gdata.call_info = &call_info;
         if ((error = gn_call_dial(&call_id, &gdata, state)) != GN_ERR_NONE) {
+		g_printf("Can't dial the phone : %s", gn_error_print(error));
 		*message=g_strdup_printf("Can't dial the phone : %s", gn_error_print(error));
 		ret = 2;
 	} else {
-		g_print("Dialled call, id: %d (lowlevel id: %d)\n", call_id, call_info.call_id);
+		g_printf("Dialled call, id: %d (lowlevel id: %d)\n", call_id, call_info.call_id);
 	}
 	 /* tear down the connection */
 	if (!phoneOpened) {
@@ -706,10 +714,12 @@ void smsBufferChanged_cb(GtkTextBuffer *textBuffer, UIComponents * uic) {
 	gtk_text_buffer_get_bounds(textBuffer, &start, &end);
 	uic->smsText = gtk_text_buffer_get_text(textBuffer, &start, &end, TRUE);
 
-	if (!uic->smsText || (count = strlen(uic->smsText)) == 0) {
-		gtk_widget_set_sensitive(uic->sendSMSButton, FALSE);
-	} else {
-		gtk_widget_set_sensitive(uic->sendSMSButton, TRUE);
+	if (!uic->noConfig) {
+		if (!uic->smsText || (count = strlen(uic->smsText)) == 0) {
+			gtk_widget_set_sensitive(uic->sendSMSButton, FALSE);
+		} else {
+			gtk_widget_set_sensitive(uic->sendSMSButton, TRUE);
+		}
 	}
 	smsSetCount(uic, count);
 	
@@ -1039,22 +1049,29 @@ int main( int argc, char *argv[] ) {
 #ifdef GNOKII_GCONF
 	if (!isGnokiiRcFileUsed(gconf_client, NULL)) {
 		gnokiiCfg = getGnokiiCfg(gconf_client, NULL);
-		gnokiiFile = TRUE;
-		state = g_new0(struct gn_statemachine,1);
-		if ((err = gn_cfg_memory_read ((const char **)gnokiiCfg)) != GN_ERR_NONE) {
-			hildon_banner_show_informationf(GTK_WIDGET(appview), GTK_STOCK_DIALOG_ERROR, _("Error reading gnokii configuration %s\n%s\n%s\n%s\n%s"), gn_error_print(err), gnokiiCfg[0], gnokiiCfg[1], gnokiiCfg[2], gnokiiCfg[3]);
-			gnokiiFile = FALSE;
-		} else if ((err = gn_cfg_phone_load(NULL, state)) != GN_ERR_NONE) {
-			fprintf(stderr, "%s\n", gn_error_print(err));
-			hildon_banner_show_informationf(GTK_WIDGET(appview), GTK_STOCK_DIALOG_ERROR, _("gn_cfg_phone_load %s"), gn_error_print(err));
-			gnokiiFile = FALSE;
+		if (gnokiiCfg) {
+			gnokiiFile = TRUE;
+			state = g_new0(struct gn_statemachine,1);
+			if ((err = gn_cfg_memory_read ((const char **)gnokiiCfg)) != GN_ERR_NONE) {
+				g_printf(_("Error reading gnokii configuration %s\n%s\n%s\n%s\n%s"), gn_error_print(err), gnokiiCfg[0], gnokiiCfg[1], gnokiiCfg[2], gnokiiCfg[3]);
+				hildon_banner_show_informationf(GTK_WIDGET(appview), GTK_STOCK_DIALOG_ERROR, _("Error reading gnokii configuration %s\n%s\n%s\n%s\n%s"), gn_error_print(err), gnokiiCfg[0], gnokiiCfg[1], gnokiiCfg[2], gnokiiCfg[3]);
+				gnokiiFile = FALSE;
+			} else if ((err = gn_cfg_phone_load(NULL, state)) != GN_ERR_NONE) {
+				g_printf(_("gn_cfg_phone_load %s"), gn_error_print(err));
+				hildon_banner_show_informationf(GTK_WIDGET(appview), GTK_STOCK_DIALOG_ERROR, _("gn_cfg_phone_load %s"), gn_error_print(err));
+				gnokiiFile = FALSE;
+			}
+		} else {
+			g_printf(_("Gnokii-GConf not configured\n"));
+			hildon_banner_show_informationf(GTK_WIDGET(appview), GTK_STOCK_DIALOG_ERROR, _("Gnokii-GConf not configured"));
 		}
 	}
 #endif
 	if (!gnokiiFile) {
 		if ((err = gn_lib_phoneprofile_load(NULL, &state)) != GN_ERR_NONE) {
-			fprintf(stderr, "%s\n", gn_error_print(err));
+			g_printf("%s\n", gn_error_print(err));
 			hildon_banner_show_information(GTK_WIDGET(appview), GTK_STOCK_DIALOG_ERROR,  gn_error_print(err));
+			uic->noConfig = TRUE;
 		}
 	}
 
@@ -1065,7 +1082,7 @@ int main( int argc, char *argv[] ) {
 	/* Initialize maemo application */
 	uic->osso_context = osso_initialize(APPLICATION_DBUS_SERVICE, VERSION, FALSE, NULL);
 
-	g_print("apres osso_init\n");
+	g_printf("apres osso_init %x\n", uic->osso_context);
 	            
 	/* Check that initialization was ok */
 	if (uic->osso_context == NULL) {
@@ -1096,6 +1113,7 @@ int main( int argc, char *argv[] ) {
 	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
 	g_signal_connect (G_OBJECT (button), "clicked",
 	                  G_CALLBACK (dialDBus_cb), (gpointer) uic);
+	gtk_widget_set_sensitive(button, !uic->noConfig);
 	gtk_table_attach_defaults(GTK_TABLE(table), button, 3, 5, 0, 1);
 	gtk_widget_grab_default(button);
 	
@@ -1160,14 +1178,14 @@ int main( int argc, char *argv[] ) {
 	/* check availability and show or hide the Buttons */
 	g_idle_add ((GSourceFunc)checkAvailability_cb, uic);
 
-	if (uic->getSms) {
-		uic->getSms = FALSE;
-		getSms(GTK_WIDGET(appview), uic);
-	}
-	
-	if (uic->getCalls) {
-		uic->getCalls = FALSE;
-		getCalls(GTK_WIDGET(appview), uic);
+	if (!uic->noConfig) {
+		if (uic->getSms) {
+			getSms(GTK_WIDGET(appview), uic);
+		}
+		
+		if (uic->getCalls) {
+			getCalls(GTK_WIDGET(appview), uic);
+		}
 	}
 	
 	/* Rest in gtk_main and wait for the fun to begin! */
